@@ -37,6 +37,9 @@ AVAILABLE_METRICS = {
         "Max-Sensitivity": MaxSensitivity,
         "Avg-Sensitivity": AvgSensitivity,
         "Consistency": Consistency,
+        "Relative Input Stability": RelativeInputStability,
+        "Relative Output Stability": RelativeOutputStability,
+        "Relative Representation Stability": RelativeRepresentationStability,
     },
     "Localisation": {
         "Pointing Game": PointingGame,
@@ -100,21 +103,56 @@ AVAILABLE_NORMALISATION_FUNCTIONS = {
 }
 
 
-AVAILABLE_XAI_METHODS = [
-    "Gradient",
-    "Saliency",
+AVAILABLE_XAI_METHODS_CAPTUM = [
     "GradientShap",
     "IntegratedGradients",
+    "DeepLift",
+    "DeepLiftShap",
     "InputXGradient",
-    "Occlusion",
+    "Saliency",
     "FeatureAblation",
-    "GradCam",
+    "Deconvolution",
+    "FeaturePermutation",
+    "Lime",
+    "KernelShap",
+    "LRP",
+    "Gradient",
+    "Occlusion",
+    "LayerGradCam",
+    "GuidedGradCam",
+    "LayerConductance",
+    "LayerActivation",
+    "InternalInfluence",
+    "LayerGradientXActivation",
     "Control Var. Sobel Filter",
     "Control Var. Constant",
     "Control Var. Random Uniform",
 ]
 
 
+DEPRECATED_XAI_METHODS_CAPTUM = {
+    "GradCam": "LayerGradCam"
+}
+
+
+AVAILABLE_XAI_METHODS_TF = [
+    "VanillaGradients",
+    "IntegratedGradients",
+    "GradientsInput",
+    "OcclusionSensitivity",
+    "GradCAM",
+    "SmoothGrad",
+]
+
+
+DEPRECATED_XAI_METHODS_TF = {
+    "Gradient": "VanillaGradients",
+    "InputXGradient": "GradientsInput",
+    "Occlusion": "OcclusionSensitivity",
+    "GradCam": "GradCAM"
+}
+
+
 def available_categories() -> List[str]:
     """
     Retrieve the available metric categories in Quantus.
@@ -139,7 +177,7 @@ def available_metrics() -> Dict[str, List[str]]:
     return {c: list(metrics.keys()) for c, metrics in AVAILABLE_METRICS.items()}
 
 
-def available_methods() -> List[str]:
+def available_methods_tf_explain() -> List[str]:
     """
     Retrieve the available explanation methods in Quantus.
 
@@ -148,7 +186,19 @@ def available_methods() -> List[str]:
     List[str]
         With the available explanation methods in Quantus.
     """
-    return [c for c in AVAILABLE_XAI_METHODS]
+    return [c for c in AVAILABLE_XAI_METHODS_TF]
+
+
+def available_methods_captum() -> List[str]:
+    """
+    Retrieve the available explanation methods in Quantus.
+
+    Returns
+    -------
+    List[str]
+        With the available explanation methods in Quantus.
+    """
+    return [c for c in AVAILABLE_XAI_METHODS_CAPTUM]
 
 
 def available_perturbation_functions() -> List[str]:
