@@ -6,302 +6,348 @@ from zennit import torchvision as ztv
 
 from quantus.functions.explanation_func import *
 from quantus.functions.normalise_func import normalise_by_max
-from tests.fixtures import *
-
-zennit_tests = [
-    # Zennit
-    (
-        lazy_fixture("load_1d_3ch_conv_model"),
-        lazy_fixture("almost_uniform_1d_no_abatch"),
-        {
-            "canonizer": None,
-            "composite": None,
-            "attributor": zattr.Gradient,
-            "xai_lib": "zennit",
-        },
-        {"shape": (10, 1, 100)},
-    ),
-    (
-        lazy_fixture("load_mnist_model"),
-        lazy_fixture("load_mnist_images"),
-        {
-            "canonizer": None,
-            "composite": None,
-            "attributor": zattr.Gradient,
-            "xai_lib": "zennit",
-        },
-        {"shape": (124, 1, 28, 28)},
-    ),
-    (
-        lazy_fixture("load_1d_3ch_conv_model"),
-        lazy_fixture("almost_uniform_1d_no_abatch"),
-        {
-            "canonizer": ztv.SequentialMergeBatchNorm,
-            "composite": zcomp.EpsilonPlus,
-            "attributor": zattr.Gradient,
-            "xai_lib": "zennit",
-        },
-        {"shape": (10, 1, 100)},
-    ),
-    (
-        lazy_fixture("load_mnist_model"),
-        lazy_fixture("load_mnist_images"),
-        {
-            "canonizer": ztv.SequentialMergeBatchNorm,
-            "composite": zcomp.EpsilonPlus,
-            "attributor": zattr.Gradient,
-            "xai_lib": "zennit",
-        },
-        {"shape": (124, 1, 28, 28)},
-    ),
-    (
-        lazy_fixture("load_1d_3ch_conv_model"),
-        lazy_fixture("almost_uniform_1d_no_abatch"),
-        {
-            "canonizer": None,
-            "composite": "epsilon_alpha2_beta1_flat",
-            "attributor": zattr.Gradient,
-        },
-        {"shape": (10, 1, 100)},
-    ),
-    (
-        lazy_fixture("load_mnist_model"),
-        lazy_fixture("load_mnist_images"),
-        {
-            "canonizer": None,
-            "composite": "epsilon_alpha2_beta1_flat",
-            "attributor": zattr.Gradient,
-        },
-        {"shape": (124, 1, 28, 28)},
-    ),
-    (
-        lazy_fixture("load_1d_3ch_conv_model"),
-        lazy_fixture("almost_uniform_1d_no_abatch"),
-        {
-            "canonizer": None,
-            "composite": "guided_backprop",
-            "attributor": zattr.Gradient,
-            "xai_lib": "zennit",
-        },
-        {"shape": (10, 1, 100)},
-    ),
-    (
-        lazy_fixture("load_mnist_model"),
-        lazy_fixture("load_mnist_images"),
-        {
-            "canonizer": None,
-            "composite": "guided_backprop",
-            "attributor": zattr.Gradient,
-            "xai_lib": "zennit",
-        },
-        {"shape": (124, 1, 28, 28)},
-    ),
-    (
-        lazy_fixture("load_mnist_model"),
-        lazy_fixture("load_mnist_images"),
-        {
-            "canonizer": None,
-            "composite": "guided_backprop",
-            "attributor": zattr.Gradient,
-            "xai_lib": "zennit",
-            "reduce_axes": (1,),
-        },
-        {"shape": (124, 1, 28, 28)},
-    ),
-    (
-        lazy_fixture("load_mnist_model"),
-        lazy_fixture("load_mnist_images"),
-        {
-            "canonizer": None,
-            "composite": "guided_backprop",
-            "attributor": zattr.Gradient,
-            "xai_lib": "zennit",
-            "reduce_axes": (1, 2),
-        },
-        {"shape": (124, 1, 1, 28)},
-    ),
-    (
-        lazy_fixture("load_mnist_model"),
-        lazy_fixture("load_mnist_images"),
-        {
-            "canonizer": None,
-            "composite": "guided_backprop",
-            "attributor": zattr.Gradient,
-            "xai_lib": "zennit",
-            "reduce_axes": (3,),
-        },
-        {"shape": (124, 1, 28, 1)},
-    ),
-    (
-        lazy_fixture("load_mnist_model"),
-        lazy_fixture("load_mnist_images"),
-        {
-            "canonizer": None,
-            "composite": "guided_backprop",
-            "attributor": zattr.Gradient,
-            "xai_lib": "zennit",
-            "reduce_axes": (0, 1),
-        },
-        {"exception": AssertionError},
-    ),
-    (
-        lazy_fixture("load_mnist_model"),
-        lazy_fixture("load_mnist_images"),
-        {
-            "canonizer": None,
-            "composite": "guided_backprop",
-            "attributor": zattr.Gradient,
-            "xai_lib": "zennit",
-            "reduce_axes": (1, 2, 3, 4, 5),
-        },
-        {"exception": AssertionError},
-    ),
-]
 
 
 @pytest.mark.explain_func
 @pytest.mark.parametrize(
     "model,data,params,expected",
-    zennit_tests
-    + [
+    [
+        # Zennit
+        (
+            lazy_fixture("load_1d_3ch_conv_model"),
+            lazy_fixture("almost_uniform_1d_no_abatch"),
+            {
+                "canonizer": None,
+                "composite": None,
+                "attributor": zattr.Gradient,
+                "xai_lib": "zennit",
+            },
+            {"shape": (10, 1, 100)},
+        ),
+        (
+            lazy_fixture("load_mnist_model"),
+            lazy_fixture("load_mnist_images"),
+            {
+                "canonizer": None,
+                "composite": None,
+                "attributor": zattr.Gradient,
+                "xai_lib": "zennit",
+            },
+            {"shape": (8, 1, 28, 28)},
+        ),
+        (
+            lazy_fixture("load_1d_3ch_conv_model"),
+            lazy_fixture("almost_uniform_1d_no_abatch"),
+            {
+                "canonizer": ztv.SequentialMergeBatchNorm,
+                "composite": zcomp.EpsilonPlus,
+                "attributor": zattr.Gradient,
+                "xai_lib": "zennit",
+            },
+            {"shape": (10, 1, 100)},
+        ),
+        (
+            lazy_fixture("load_mnist_model"),
+            lazy_fixture("load_mnist_images"),
+            {
+                "canonizer": ztv.SequentialMergeBatchNorm,
+                "composite": zcomp.EpsilonPlus,
+                "attributor": zattr.Gradient,
+                "xai_lib": "zennit",
+            },
+            {"shape": (8, 1, 28, 28)},
+        ),
+        (
+            lazy_fixture("load_1d_3ch_conv_model"),
+            lazy_fixture("almost_uniform_1d_no_abatch"),
+            {
+                "canonizer": None,
+                "composite": "epsilon_alpha2_beta1_flat",
+                "attributor": zattr.Gradient,
+            },
+            {"shape": (10, 1, 100)},
+        ),
+        (
+            lazy_fixture("load_mnist_model"),
+            lazy_fixture("load_mnist_images"),
+            {
+                "canonizer": None,
+                "composite": "epsilon_alpha2_beta1_flat",
+                "attributor": zattr.Gradient,
+            },
+            {"shape": (8, 1, 28, 28)},
+        ),
+        (
+            lazy_fixture("load_1d_3ch_conv_model"),
+            lazy_fixture("almost_uniform_1d_no_abatch"),
+            {
+                "canonizer": None,
+                "composite": "guided_backprop",
+                "attributor": zattr.Gradient,
+                "xai_lib": "zennit",
+            },
+            {"shape": (10, 1, 100)},
+        ),
+        (
+            lazy_fixture("load_mnist_model"),
+            lazy_fixture("load_mnist_images"),
+            {
+                "canonizer": None,
+                "composite": "guided_backprop",
+                "attributor": zattr.Gradient,
+                "xai_lib": "zennit",
+            },
+            {"shape": (8, 1, 28, 28)},
+        ),
+        (
+            lazy_fixture("load_mnist_model"),
+            lazy_fixture("load_mnist_images"),
+            {
+                "canonizer": None,
+                "composite": "guided_backprop",
+                "attributor": zattr.Gradient,
+                "xai_lib": "zennit",
+                "reduce_axes": (1,),
+            },
+            {"shape": (8, 1, 28, 28)},
+        ),
+        (
+            lazy_fixture("load_mnist_model"),
+            lazy_fixture("load_mnist_images"),
+            {
+                "canonizer": None,
+                "composite": "guided_backprop",
+                "attributor": zattr.Gradient,
+                "xai_lib": "zennit",
+                "reduce_axes": (1, 2),
+            },
+            {"shape": (8, 1, 1, 28)},
+        ),
+        (
+            lazy_fixture("load_mnist_model"),
+            lazy_fixture("load_mnist_images"),
+            {
+                "canonizer": None,
+                "composite": "guided_backprop",
+                "attributor": zattr.Gradient,
+                "xai_lib": "zennit",
+                "reduce_axes": (3,),
+            },
+            {"shape": (8, 1, 28, 1)},
+        ),
+        (
+            lazy_fixture("load_mnist_model"),
+            lazy_fixture("load_mnist_images"),
+            {
+                "canonizer": None,
+                "composite": "guided_backprop",
+                "attributor": zattr.Gradient,
+                "xai_lib": "zennit",
+                "reduce_axes": (0, 1),
+            },
+            {"exception": AssertionError},
+        ),
+        (
+            lazy_fixture("load_mnist_model"),
+            lazy_fixture("load_mnist_images"),
+            {
+                "canonizer": None,
+                "composite": "guided_backprop",
+                "attributor": zattr.Gradient,
+                "xai_lib": "zennit",
+                "reduce_axes": (1, 2, 3, 4, 5),
+            },
+            {"exception": AssertionError},
+        ),
         # Captum
         (
             lazy_fixture("load_1d_3ch_conv_model"),
             lazy_fixture("almost_uniform_1d_no_abatch"),
-            {"method": "Saliency",},
+            {
+                "method": "Saliency",
+            },
             {"shape": (10, 1, 100)},
         ),
         (
             lazy_fixture("load_mnist_model"),
             lazy_fixture("load_mnist_images"),
-            {"method": "Saliency",},
-            {"shape": (124, 1, 28, 28)},
+            {
+                "method": "Saliency",
+            },
+            {"shape": (8, 1, 28, 28)},
         ),
         (
             lazy_fixture("load_1d_3ch_conv_model"),
             lazy_fixture("almost_uniform_1d_no_abatch"),
-            {"method": "GradientShap",},
+            {
+                "method": "GradientShap",
+            },
             {"shape": (10, 1, 100)},
         ),
         (
             lazy_fixture("load_mnist_model"),
             lazy_fixture("load_mnist_images"),
-            {"method": "GradientShap",},
-            {"shape": (124, 1, 28, 28)},
+            {
+                "method": "GradientShap",
+            },
+            {"shape": (8, 1, 28, 28)},
         ),
         (
             lazy_fixture("load_1d_3ch_conv_model"),
             lazy_fixture("almost_uniform_1d_no_abatch"),
-            {"method": "IntegratedGradients",},
+            {
+                "method": "IntegratedGradients",
+            },
             {"shape": (10, 1, 100)},
         ),
         (
             lazy_fixture("load_mnist_model"),
             lazy_fixture("load_mnist_images"),
-            {"method": "IntegratedGradients",},
-            {"shape": (124, 1, 28, 28)},
+            {
+                "method": "IntegratedGradients",
+            },
+            {"shape": (8, 1, 28, 28)},
         ),
         (
             lazy_fixture("load_1d_3ch_conv_model"),
             lazy_fixture("almost_uniform_1d_no_abatch"),
-            {"method": "InputXGradient",},
+            {
+                "method": "InputXGradient",
+            },
             {"shape": (10, 1, 100)},
         ),
         (
             lazy_fixture("load_mnist_model"),
             lazy_fixture("load_mnist_images"),
-            {"method": "InputXGradient",},
-            {"shape": (124, 1, 28, 28)},
+            {
+                "method": "InputXGradient",
+            },
+            {"shape": (8, 1, 28, 28)},
         ),
         (
             lazy_fixture("load_1d_3ch_conv_model"),
             lazy_fixture("almost_uniform_1d_no_abatch"),
-            {"method": "Occlusion",},
+            {
+                "method": "Occlusion",
+            },
             {"shape": (10, 1, 100)},
         ),
         (
             lazy_fixture("load_mnist_model"),
             lazy_fixture("load_mnist_images"),
-            {"method": "Occlusion",},
-            {"shape": (124, 1, 28, 28)},
+            {
+                "method": "Occlusion",
+            },
+            {"shape": (8, 1, 28, 28)},
         ),
         (
             lazy_fixture("load_1d_3ch_conv_model"),
             lazy_fixture("almost_uniform_1d_no_abatch"),
-            {"method": "FeatureAblation",},
+            {
+                "method": "FeatureAblation",
+            },
             {"shape": (10, 1, 100)},
         ),
         (
             lazy_fixture("load_mnist_model"),
             lazy_fixture("load_mnist_images"),
-            {"method": "FeatureAblation",},
-            {"shape": (124, 1, 28, 28)},
+            {
+                "method": "FeatureAblation",
+            },
+            {"shape": (8, 1, 28, 28)},
         ),
         (
             lazy_fixture("load_1d_3ch_conv_model"),
             lazy_fixture("almost_uniform_1d_no_abatch"),
-            {"method": "GradCam", "gc_layer": "model._modules.get('conv_2')",},
-            {"shape": (10, 1, 44)},
-        ),
-        (
-            lazy_fixture("load_mnist_model"),
-            lazy_fixture("load_mnist_images"),
-            {"method": "GradCam", "gc_layer": "model._modules.get('conv_2')",},
-            {"shape": (124, 1, 8, 8)},
-        ),
-        (
-            lazy_fixture("load_1d_3ch_conv_model"),
-            lazy_fixture("almost_uniform_1d_no_abatch"),
-            {"method": "Control Var. Sobel Filter",},
+            {"method": "LayerGradCam", "gc_layer": "model._modules.get('conv_2')", "interpolate": (100,), "interpolate_method": "nearest"},
             {"shape": (10, 1, 100)},
         ),
         (
             lazy_fixture("load_mnist_model"),
             lazy_fixture("load_mnist_images"),
-            {"method": "Control Var. Sobel Filter",},
-            {"shape": (124, 1, 28, 28)},
+            {"method": "LayerGradCam", "gc_layer": "model._modules.get('conv_2')", "interpolate": (28, 28)},
+            {"shape": (8, 1, 28, 28)},
+        ),
+        (
+            lazy_fixture("load_mnist_model"),
+            lazy_fixture("load_mnist_images"),
+            {"method": "GradCam", "gc_layer": "model._modules.get('conv_2')"},
+            {"shape": (8, 1, 8, 8)},
         ),
         (
             lazy_fixture("load_1d_3ch_conv_model"),
             lazy_fixture("almost_uniform_1d_no_abatch"),
-            {"method": "Gradient",},
+            {
+                "method": "Control Var. Sobel Filter",
+            },
             {"shape": (10, 1, 100)},
         ),
         (
             lazy_fixture("load_mnist_model"),
             lazy_fixture("load_mnist_images"),
-            {"method": "Gradient",},
-            {"shape": (124, 1, 28, 28)},
+            {
+                "method": "Control Var. Sobel Filter",
+            },
+            {"shape": (8, 1, 28, 28)},
         ),
         (
             lazy_fixture("load_1d_3ch_conv_model"),
             lazy_fixture("almost_uniform_1d_no_abatch"),
-            {"method": "Control Var. Constant", "constant_value": 0.0,},
+            {
+                "method": "Gradient",
+            },
+            {"shape": (10, 1, 100)},
+        ),
+        (
+            lazy_fixture("load_mnist_model"),
+            lazy_fixture("load_mnist_images"),
+            {
+                "method": "Gradient",
+            },
+            {"shape": (8, 1, 28, 28)},
+        ),
+        (
+            lazy_fixture("load_1d_3ch_conv_model"),
+            lazy_fixture("almost_uniform_1d_no_abatch"),
+            {
+                "method": "Control Var. Constant",
+                "constant_value": 0.0,
+            },
             {"value": 0.0},
         ),
         (
             lazy_fixture("load_mnist_model"),
             lazy_fixture("load_mnist_images"),
-            {"method": "Control Var. Constant", "constant_value": 0.0,},
+            {
+                "method": "Control Var. Constant",
+                "constant_value": 0.0,
+            },
             {"value": 0.0},
         ),
         (
             lazy_fixture("load_mnist_model"),
             lazy_fixture("load_mnist_images"),
-            {"method": "Control Var. Random Uniform",},
+            {
+                "method": "Control Var. Random Uniform",
+            },
             {"min": 0.0, "max": 1.0},
         ),
         (
             lazy_fixture("load_1d_3ch_conv_model"),
             lazy_fixture("almost_uniform_1d_no_abatch"),
-            {"method": "Control Var. Random Uniform",},
+            {
+                "method": "Control Var. Random Uniform",
+            },
             {"min": 0.0, "max": 1.0},
         ),
         (
             lazy_fixture("load_mnist_model"),
             lazy_fixture("load_mnist_images"),
-            {"method": "Gradient", "reduce_axes": (1,),},
-            {"shape": (124, 1, 28, 28)},
+            {
+                "method": "Gradient",
+                "reduce_axes": (1,),
+            },
+            {"shape": (8, 1, 28, 28)},
         ),
         (
             lazy_fixture("load_mnist_model"),
@@ -313,50 +359,226 @@ zennit_tests = [
                 "normalise_func": normalise_by_max,
                 "reduce_axes": (1, 2),
             },
-            {"shape": (124, 1, 1, 28)},
+            {"shape": (8, 1, 1, 28)},
         ),
         (
             lazy_fixture("load_mnist_model"),
             lazy_fixture("load_mnist_images"),
-            {"method": "Gradient", "reduce_axes": (3,),},
-            {"shape": (124, 1, 28, 1)},
+            {
+                "method": "Gradient",
+                "reduce_axes": (3,),
+            },
+            {"shape": (8, 1, 28, 1)},
         ),
         (
             lazy_fixture("load_mnist_model"),
             lazy_fixture("load_mnist_images"),
-            {"method": "Gradient", "reduce_axes": (0, 1),},
+            {
+                "method": "Gradient",
+                "reduce_axes": (0, 1),
+            },
             {"exception": AssertionError},
         ),
         (
             lazy_fixture("load_mnist_model"),
             lazy_fixture("load_mnist_images"),
-            {"method": "Gradient", "reduce_axes": (1, 2, 3, 4, 5, 6),},
+            {
+                "method": "Gradient",
+                "reduce_axes": (1, 2, 3, 4, 5, 6),
+            },
             {"exception": AssertionError},
         ),
+        (
+            lazy_fixture("load_mnist_model"),
+            lazy_fixture("load_mnist_images"),
+            {"method": "DeepLift"},
+            {"shape": (8, 1, 28, 28)},
+        ),
+        (
+            lazy_fixture("load_1d_3ch_conv_model"),
+            lazy_fixture("almost_uniform_1d_no_abatch"),
+            {"method": "DeepLift"},
+            {"shape": (10, 1, 100)},
+        ),
+        (
+            lazy_fixture("load_mnist_model"),
+            lazy_fixture("load_mnist_images"),
+            {"method": "DeepLiftShap"},
+            {"shape": (8, 1, 28, 28)},
+        ),
+        (
+            lazy_fixture("load_1d_3ch_conv_model"),
+            lazy_fixture("almost_uniform_1d_no_abatch"),
+            {"method": "DeepLiftShap"},
+            {"shape": (10, 1, 100)},
+        ),
+        (
+            lazy_fixture("load_mnist_model"),
+            lazy_fixture("load_mnist_images"),
+            {"method": "GuidedGradCam", "gc_layer": "model._modules.get('conv_2')",},
+            {"shape": (8, 1, 28, 28)},
+        ),
+        (
+            lazy_fixture("load_1d_3ch_conv_model"),
+            lazy_fixture("almost_uniform_1d_no_abatch"),
+            {"method": "GuidedGradCam", "gc_layer": "model._modules.get('conv_2')",},
+            {"shape": (10, 1, 100)},
+        ),
+        (
+            lazy_fixture("load_mnist_model"),
+            lazy_fixture("load_mnist_images"),
+            {"method": "Deconvolution", },
+            {"shape": (8, 1, 28, 28)},
+        ),
+        (
+            lazy_fixture("load_1d_3ch_conv_model"),
+            lazy_fixture("almost_uniform_1d_no_abatch"),
+            {"method": "Deconvolution", },
+            {"shape": (10, 1, 100)},
+        ),
+        (
+            lazy_fixture("load_mnist_model"),
+            lazy_fixture("load_mnist_images"),
+            {"method": "FeaturePermutation", },
+            {"shape": (8, 1, 28, 28)},
+        ),
+        (
+            lazy_fixture("load_1d_3ch_conv_model"),
+            lazy_fixture("almost_uniform_1d_no_abatch"),
+            {"method": "FeaturePermutation", },
+            {"shape": (10, 1, 100)},
+        ),
+        (
+            lazy_fixture("load_mnist_model"),
+            lazy_fixture("load_mnist_images"),
+            {"method": "Lime", },
+            {"shape": (8, 1, 28, 28)},
+        ),
+        (
+            lazy_fixture("load_1d_3ch_conv_model"),
+            lazy_fixture("almost_uniform_1d_no_abatch"),
+            {"method": "Lime", },
+            {"shape": (10, 1, 100)},
+        ),
+        (
+            lazy_fixture("load_mnist_model"),
+            lazy_fixture("load_mnist_images"),
+            {"method": "KernelShap", },
+            {"shape": (8, 1, 28, 28)},
+        ),
+        (
+            lazy_fixture("load_1d_3ch_conv_model"),
+            lazy_fixture("almost_uniform_1d_no_abatch"),
+            {"method": "KernelShap", },
+            {"shape": (10, 1, 100)},
+        ),
+        (
+            lazy_fixture("load_mnist_model"),
+            lazy_fixture("load_mnist_images"),
+            {"method": "LRP", },
+            {"shape": (8, 1, 28, 28)},
+        ),
+        (
+            lazy_fixture("load_mnist_model"),
+            lazy_fixture("load_mnist_images"),
+            {"method": "LayerConductance", "gc_layer": "model._modules.get('conv_2')",
+             "interpolate": (28, 28), "interpolate_mode": "nearest"},
+            {"shape": (8, 1, 28, 28)},
+        ),
+        (
+            lazy_fixture("load_1d_3ch_conv_model"),
+            lazy_fixture("almost_uniform_1d_no_abatch"),
+            {"method": "LayerConductance", "gc_layer": "model._modules.get('conv_2')",
+             "interpolate": (100,), "interpolate_mode": "nearest"},
+            {"shape": (10, 1, 100)},
+        ),
+        (
+            lazy_fixture("load_mnist_model"),
+            lazy_fixture("load_mnist_images"),
+            {"method": "LayerActivation", "gc_layer": "model._modules.get('conv_2')",
+             "interpolate": (28, 28), "interpolate_mode": "nearest"},
+            {"shape": (8, 1, 28, 28)},
+        ),
+        (
+            lazy_fixture("load_1d_3ch_conv_model"),
+            lazy_fixture("almost_uniform_1d_no_abatch"),
+            {"method": "LayerActivation", "gc_layer": "model._modules.get('conv_2')",
+             "interpolate": (100,), "interpolate_mode": "nearest"},
+            {"shape": (10, 1, 100)},
+        ),
+        (
+            lazy_fixture("load_mnist_model"),
+            lazy_fixture("load_mnist_images"),
+            {"method": "InternalInfluence", "gc_layer": "model._modules.get('conv_2')",
+             "interpolate": (28, 28), "interpolate_mode": "nearest"},
+            {"shape": (8, 1, 28, 28)},
+        ),
+        (
+            lazy_fixture("load_1d_3ch_conv_model"),
+            lazy_fixture("almost_uniform_1d_no_abatch"),
+            {"method": "InternalInfluence", "gc_layer": "model._modules.get('conv_2')",
+             "interpolate": (100,), "interpolate_mode": "nearest"},
+            {"shape": (10, 1, 100)},
+        ),
+        (
+            lazy_fixture("load_mnist_model"),
+            lazy_fixture("load_mnist_images"),
+            {"method": "LayerGradientXActivation", "method_kwargs": {"layer": "model._modules.get('conv_2')"},
+             "interpolate": (28, 28), "interpolate_mode": "nearest"},
+            {"shape": (8, 1, 28, 28)},
+        ),
+        (
+            lazy_fixture("load_1d_3ch_conv_model"),
+            lazy_fixture("almost_uniform_1d_no_abatch"),
+            {"method": "LayerGradientXActivation", "gc_layer": "model._modules.get('conv_2')",
+             "interpolate": (100,), "interpolate_mode": "nearest"},
+            {"shape": (10, 1, 100)},
+        ),
+        (
+            lazy_fixture("load_1d_3ch_conv_model"),
+            lazy_fixture("almost_uniform_1d_no_abatch"),
+            {"method": "LayerGradientXActivation", "method_kwargs": {},
+             "interpolate": (100,), "interpolate_mode": "nearest"},
+            {"exception": ValueError},
+        ),
         # tf-explain
         (
             lazy_fixture("load_mnist_model_tf"),
             lazy_fixture("load_mnist_images_tf"),
-            {"method": "Gradient",},
-            {"shape": (124, 28, 28)},
+            {"method": "VanillaGradients",},
+            {"shape": (8, 28, 28)},
         ),
         (
             lazy_fixture("load_mnist_model_tf"),
             lazy_fixture("load_mnist_images_tf"),
-            {"method": "Occlusion",},
-            {"shape": (124, 28, 28, 3)},
+            {"method": "Gradient", },
+            {"shape": (8, 28, 28)},
         ),
         (
             lazy_fixture("load_mnist_model_tf"),
             lazy_fixture("load_mnist_images_tf"),
-            {"method": "IntegratedGradients",},
-            {"shape": (124, 28, 28)},
+            {"method": "OcclusionSensitivity",},
+            {"shape": (8, 28, 28, 3)},
         ),
         (
             lazy_fixture("load_mnist_model_tf"),
             lazy_fixture("load_mnist_images_tf"),
-            {"method": "InputXGradient",},
-            {"shape": (124, 28, 28)},
+            {
+                "method": "IntegratedGradients",
+            },
+            {"shape": (8, 28, 28)},
+        ),
+        (
+            lazy_fixture("load_mnist_model_tf"),
+            lazy_fixture("load_mnist_images_tf"),
+            {"method": "GradientsInput",},
+            {"shape": (8, 28, 28)},
+        ),
+        (
+            lazy_fixture("load_mnist_model_tf"),
+            lazy_fixture("load_mnist_images_tf"),
+            {"method": "SmoothGrad", },
+            {"shape": (8, 28, 28)},
         ),
         (
             lazy_fixture("load_mnist_model_tf"),
@@ -364,11 +586,16 @@ zennit_tests = [
             {},
             {"warning": UserWarning},
         ),
-        (None, lazy_fixture("load_mnist_images_tf"), {}, {"exception": ValueError},),
+        (
+            None,
+            lazy_fixture("load_mnist_images_tf"),
+            {},
+            {"exception": ValueError},
+        ),
         (
             lazy_fixture("load_mnist_model_tf"),
             lazy_fixture("load_mnist_images_tf"),
-            {"method": "InputXGradient", "reduce_axes": (0, 1, 2)},
+            {"method": "GradientsInput", "reduce_axes": (0, 1, 2)},
             {"exception": KeyError},
         ),
     ],
@@ -419,37 +646,47 @@ def test_explain_func(
         (
             lazy_fixture("load_1d_3ch_conv_model"),
             lazy_fixture("almost_uniform_1d_no_abatch"),
-            {"method": "Saliency",},
+            {
+                "method": "Saliency",
+            },
             {"shape": (10, 1, 100)},
         ),
         (
             lazy_fixture("load_mnist_model"),
             lazy_fixture("load_mnist_images"),
-            {"method": "Saliency",},
-            {"shape": (124, 1, 28, 28)},
+            {
+                "method": "Saliency",
+            },
+            {"shape": (8, 1, 28, 28)},
         ),
         (
             lazy_fixture("load_1d_3ch_conv_model"),
             lazy_fixture("almost_uniform_1d_no_abatch"),
-            {"method": "Control Var. Constant", "constant_value": 0.0,},
+            {
+                "method": "Control Var. Constant",
+                "constant_value": 0.0,
+            },
             {"value": 0.0},
         ),
         (
             lazy_fixture("load_mnist_model"),
             lazy_fixture("load_mnist_images"),
-            {"method": "Control Var. Constant", "constant_value": 0.0,},
+            {
+                "method": "Control Var. Constant",
+                "constant_value": 0.0,
+            },
             {"value": 0.0},
         ),
         (
             lazy_fixture("load_1d_3ch_conv_model"),
             lazy_fixture("almost_uniform_1d_no_abatch"),
-            {"method": "GradCam",},
+            {"method": "LayerGradCam",},
             {"exception": ValueError},
         ),
         (
             lazy_fixture("load_mnist_model"),
             lazy_fixture("load_mnist_images"),
-            {"method": "GradCam",},
+            {"method": "LayerGradCam",},
             {"exception": ValueError},
         ),
     ],
@@ -499,73 +736,77 @@ def test_generate_captum_explanation(
         (
             lazy_fixture("load_1d_3ch_conv_model_tf"),
             lazy_fixture("almost_uniform_1d_no_abatch_channel_last"),
-            {"method": "Gradient",},
+            {"method": "VanillaGradients",},
             {"exception": ValueError},
         ),
         (
             lazy_fixture("load_mnist_model_tf"),
             lazy_fixture("load_mnist_images_tf"),
-            {"method": "Gradient",},
-            {"shape": (124, 28, 28)},
+            {"method": "VanillaGradients",},
+            {"shape": (8, 28, 28)},
         ),
         (
             lazy_fixture("load_1d_3ch_conv_model_tf"),
             lazy_fixture("almost_uniform_1d_no_abatch_channel_last"),
-            {"method": "Occlusion",},
+            {"method": "OcclusionSensitivity",},
             {"exception": IndexError},
         ),
         (
             lazy_fixture("load_mnist_model_tf"),
             lazy_fixture("load_mnist_images_tf"),
-            {"method": "Occlusion",},
-            {"shape": (124, 28, 28, 3)},
+            {"method": "OcclusionSensitivity",},
+            {"shape": (8, 28, 28, 3)},
         ),
         (
             lazy_fixture("load_1d_3ch_conv_model_tf"),
             lazy_fixture("almost_uniform_1d_no_abatch_channel_last"),
-            {"method": "InputXGradient",},
+            {"method": "GradientsInput",},
             {"exception": ValueError},
         ),
         (
             lazy_fixture("load_mnist_model_tf"),
             lazy_fixture("load_mnist_images_tf"),
-            {"method": "InputXGradient",},
-            {"shape": (124, 28, 28)},
+            {"method": "GradientsInput",},
+            {"shape": (8, 28, 28)},
         ),
         (
             lazy_fixture("load_1d_3ch_conv_model_tf"),
             lazy_fixture("almost_uniform_1d_no_abatch_channel_last"),
-            {"method": "IntegratedGradients",},
+            {
+                "method": "IntegratedGradients",
+            },
             {"exception": ValueError},
         ),
         (
             lazy_fixture("load_mnist_model_tf"),
             lazy_fixture("load_mnist_images_tf"),
-            {"method": "IntegratedGradients",},
-            {"shape": (124, 28, 28)},
+            {
+                "method": "IntegratedGradients",
+            },
+            {"shape": (8, 28, 28)},
         ),
         (
             lazy_fixture("load_1d_3ch_conv_model_tf"),
             lazy_fixture("almost_uniform_1d_no_abatch_channel_last"),
-            {"method": "GradCam",},
+            {"method": "GradCAM",},
             {"exception": ValueError},
         ),
         (
             lazy_fixture("load_mnist_model_tf"),
             lazy_fixture("load_mnist_images_tf"),
-            {"method": "GradCam",},
-            {"exception": ValueError},
+            {"method": "GradCAM",},
+            {"shape": (8, 28, 28, 3)},
         ),
         (
             lazy_fixture("load_1d_3ch_conv_model_tf"),
             lazy_fixture("almost_uniform_1d_no_abatch_channel_last"),
-            {"method": "GradCam", "gc_layer": "dense_1",},
+            {"method": "GradCAM", "gc_layer": "dense_1",},
             {"exception": Exception},
         ),
         (
             lazy_fixture("load_mnist_model_tf"),
             lazy_fixture("load_mnist_images_tf"),
-            {"method": "GradCam", "gc_layer": "dense_1",},
+            {"method": "GradCAM", "gc_layer": "dense_1",},
             {"exception": ValueError},
         ),
     ],
@@ -615,25 +856,29 @@ def test_generate_tf_explanation(
         (
             lazy_fixture("load_mnist_model_tf"),
             lazy_fixture("load_mnist_images_tf"),
-            {"method": "Gradient",},
-            {"shape": (124, 28, 28)},
+            {"method": "VanillaGradients",},
+            {"shape": (8, 28, 28)},
         ),
         (
             lazy_fixture("load_1d_3ch_conv_model_tf"),
             lazy_fixture("almost_uniform_1d_no_abatch_channel_last"),
-            {"method": "Gradient",},
+            {"method": "VanillaGradients",},
             {"exception": ValueError},
         ),
         (
             lazy_fixture("load_mnist_model"),
             lazy_fixture("load_mnist_images"),
-            {"method": "Gradient",},
-            {"shape": (124, 1, 28, 28)},
+            {
+                "method": "Gradient",
+            },
+            {"shape": (8, 1, 28, 28)},
         ),
         (
             lazy_fixture("load_1d_3ch_conv_model"),
             lazy_fixture("almost_uniform_1d_no_abatch"),
-            {"method": "Gradient",},
+            {
+                "method": "Gradient",
+            },
             {"shape": (10, 1, 100)},
         ),
     ],
