@@ -2,10 +2,10 @@ from typing import Union
 
 import pytest
 from pytest_lazyfixture import lazy_fixture
+import numpy as np
 
 from quantus.functions.explanation_func import explain
 from quantus.metrics.axiomatic import Completeness, InputInvariance, NonSensitivity
-from tests.fixtures import *
 
 
 @pytest.mark.axiomatic
@@ -37,7 +37,9 @@ from tests.fixtures import *
                 },
                 "call": {
                     "explain_func": explain,
-                    "explain_func_kwargs": {"method": "Saliency",},
+                    "explain_func_kwargs": {
+                        "method": "Saliency",
+                    },
                 },
             },
             1.0,
@@ -54,7 +56,9 @@ from tests.fixtures import *
                 },
                 "call": {
                     "explain_func": explain,
-                    "explain_func_kwargs": {"method": "Saliency",},
+                    "explain_func_kwargs": {
+                        "method": "Saliency",
+                    },
                 },
             },
             1.0,
@@ -71,7 +75,9 @@ from tests.fixtures import *
                 },
                 "call": {
                     "explain_func": explain,
-                    "explain_func_kwargs": {"method": "Saliency",},
+                    "explain_func_kwargs": {
+                        "method": "Saliency",
+                    },
                 },
             },
             1.0,
@@ -88,7 +94,9 @@ from tests.fixtures import *
                 },
                 "call": {
                     "explain_func": explain,
-                    "explain_func_kwargs": {"method": "Saliency",},
+                    "explain_func_kwargs": {
+                        "method": "Saliency",
+                    },
                 },
             },
             1.0,
@@ -105,7 +113,9 @@ from tests.fixtures import *
                 },
                 "call": {
                     "explain_func": explain,
-                    "explain_func_kwargs": {"method": "Saliency",},
+                    "explain_func_kwargs": {
+                        "method": "Saliency",
+                    },
                 },
             },
             1.0,
@@ -122,7 +132,9 @@ from tests.fixtures import *
                 },
                 "call": {
                     "explain_func": explain,
-                    "explain_func_kwargs": {"method": "Saliency",},
+                    "explain_func_kwargs": {
+                        "method": "Saliency",
+                    },
                 },
             },
             1.0,
@@ -139,7 +151,9 @@ from tests.fixtures import *
                 },
                 "call": {
                     "explain_func": explain,
-                    "explain_func_kwargs": {"method": "Saliency",},
+                    "explain_func_kwargs": {
+                        "method": "Saliency",
+                    },
                 },
             },
             1.0,
@@ -156,7 +170,9 @@ from tests.fixtures import *
                 },
                 "call": {
                     "explain_func": explain,
-                    "explain_func_kwargs": {"method": "Saliency",},
+                    "explain_func_kwargs": {
+                        "method": "Saliency",
+                    },
                 },
             },
             1.0,
@@ -164,7 +180,10 @@ from tests.fixtures import *
     ],
 )
 def test_completeness(
-    model, data: np.ndarray, params: dict, expected: Union[float, dict, bool],
+    model,
+    data: np.ndarray,
+    params: dict,
+    expected: Union[float, dict, bool],
 ):
     x_batch, y_batch = (
         data["x_batch"],
@@ -178,7 +197,10 @@ def test_completeness(
         explain = call_params["explain_func"]
         explain_func_kwargs = call_params.get("explain_func_kwargs", {})
         a_batch = explain(
-            model=model, inputs=x_batch, targets=y_batch, **explain_func_kwargs,
+            model=model,
+            inputs=x_batch,
+            targets=y_batch,
+            **explain_func_kwargs,
         )
     elif "a_batch" in data:
         a_batch = data["a_batch"]
@@ -186,7 +208,11 @@ def test_completeness(
         a_batch = None
 
     scores = Completeness(**init_params)(
-        model=model, x_batch=x_batch, y_batch=y_batch, a_batch=a_batch, **call_params,
+        model=model,
+        x_batch=x_batch,
+        y_batch=y_batch,
+        a_batch=a_batch,
+        **call_params,
     )
 
     assert scores is not None, "Test failed."
@@ -209,7 +235,9 @@ def test_completeness(
                 },
                 "call": {
                     "explain_func": explain,
-                    "explain_func_kwargs": {"method": "Saliency",},
+                    "explain_func_kwargs": {
+                        "method": "Saliency",
+                    },
                 },
             },
             1.0,
@@ -227,7 +255,9 @@ def test_completeness(
                 },
                 "call": {
                     "explain_func": explain,
-                    "explain_func_kwargs": {"method": "Saliency",},
+                    "explain_func_kwargs": {
+                        "method": "Saliency",
+                    },
                 },
             },
             1.0,
@@ -246,7 +276,9 @@ def test_completeness(
                 },
                 "call": {
                     "explain_func": explain,
-                    "explain_func_kwargs": {"method": "Saliency",},
+                    "explain_func_kwargs": {
+                        "method": "Saliency",
+                    },
                 },
             },
             1.0,
@@ -265,7 +297,9 @@ def test_completeness(
                 },
                 "call": {
                     "explain_func": explain,
-                    "explain_func_kwargs": {"method": "Saliency",},
+                    "explain_func_kwargs": {
+                        "method": "Saliency",
+                    },
                 },
             },
             1.0,
@@ -283,7 +317,9 @@ def test_completeness(
                 },
                 "call": {
                     "explain_func": explain,
-                    "explain_func_kwargs": {"method": "Saliency",},
+                    "explain_func_kwargs": {
+                        "method": "Saliency",
+                    },
                 },
             },
             1.0,
@@ -301,7 +337,9 @@ def test_completeness(
                 },
                 "call": {
                     "explain_func": explain,
-                    "explain_func_kwargs": {"method": "Saliency",},
+                    "explain_func_kwargs": {
+                        "method": "Saliency",
+                    },
                 },
             },
             1.0,
@@ -320,7 +358,9 @@ def test_completeness(
                 },
                 "call": {
                     "explain_func": explain,
-                    "explain_func_kwargs": {"method": "Saliency",},
+                    "explain_func_kwargs": {
+                        "method": "Saliency",
+                    },
                 },
             },
             1.0,
@@ -339,7 +379,9 @@ def test_completeness(
                 },
                 "call": {
                     "explain_func": explain,
-                    "explain_func_kwargs": {"method": "Saliency",},
+                    "explain_func_kwargs": {
+                        "method": "Saliency",
+                    },
                 },
             },
             1.0,
@@ -347,7 +389,10 @@ def test_completeness(
     ],
 )
 def test_non_sensitivity(
-    model, data: np.ndarray, params: dict, expected: Union[float, dict, bool],
+    model,
+    data: np.ndarray,
+    params: dict,
+    expected: Union[float, dict, bool],
 ):
     x_batch, y_batch = (
         data["x_batch"],
@@ -361,7 +406,10 @@ def test_non_sensitivity(
         explain = call_params["explain_func"]
         explain_func_kwargs = call_params.get("explain_func_kwargs", {})
         a_batch = explain(
-            model=model, inputs=x_batch, targets=y_batch, **explain_func_kwargs,
+            model=model,
+            inputs=x_batch,
+            targets=y_batch,
+            **explain_func_kwargs,
         )
     elif "a_batch" in data:
         a_batch = data["a_batch"]
@@ -369,7 +417,11 @@ def test_non_sensitivity(
         a_batch = None
 
     scores = NonSensitivity(**init_params)(
-        model=model, x_batch=x_batch, y_batch=y_batch, a_batch=a_batch, **call_params,
+        model=model,
+        x_batch=x_batch,
+        y_batch=y_batch,
+        a_batch=a_batch,
+        **call_params,
     )
     assert scores is not None, "Test failed."
 
@@ -392,7 +444,9 @@ def test_non_sensitivity(
                 },
                 "call": {
                     "explain_func": explain,
-                    "explain_func_kwargs": {"method": "Gradient",},
+                    "explain_func_kwargs": {
+                        "method": "Gradient",
+                    },
                 },
             },
             {"dtypes": [True, False]},
@@ -411,7 +465,9 @@ def test_non_sensitivity(
                 },
                 "call": {
                     "explain_func": explain,
-                    "explain_func_kwargs": {"method": "Gradient",},
+                    "explain_func_kwargs": {
+                        "method": "Gradient",
+                    },
                 },
             },
             {"dtypes": [True, False]},
@@ -430,7 +486,8 @@ def test_non_sensitivity(
                 },
                 "call": {
                     "explain_func": explain,
-                    "explain_func_kwargs": {"method": "InputxGradient",},
+                    "explain_func_kwargs": {
+                        "method": "InputXGradient",},
                 },
             },
             {"dtypes": [True, False]},
@@ -449,7 +506,9 @@ def test_non_sensitivity(
                 },
                 "call": {
                     "explain_func": explain,
-                    "explain_func_kwargs": {"method": "Saliency",},
+                    "explain_func_kwargs": {
+                        "method": "Saliency",
+                    },
                 },
             },
             {"dtypes": [True, False]},
@@ -468,7 +527,9 @@ def test_non_sensitivity(
                 },
                 "call": {
                     "explain_func": explain,
-                    "explain_func_kwargs": {"method": "Saliency",},
+                    "explain_func_kwargs": {
+                        "method": "Saliency",
+                    },
                 },
             },
             {"dtypes": [True, False]},
@@ -485,6 +546,27 @@ def test_non_sensitivity(
                     "disable_warnings": True,
                     "display_progressbar": True,
                 },
+                "call": {
+                    "explain_func": explain,
+                    "explain_func_kwargs": {
+                        "method": "InputXGradient",
+                    },
+                },
+            },
+            {"dtypes": [True, False]},
+        ),
+        (
+            lazy_fixture("load_1d_3ch_conv_model"),
+            lazy_fixture("almost_uniform_1d"),
+            {
+                "a_batch_generate": False,
+                "init": {
+                    "abs": False,
+                    "normalise": False,
+                    "input_shift": -1,
+                    "disable_warnings": True,
+                    "display_progressbar": False,
+                },
                 "call": {
                     "explain_func": explain,
                     "explain_func_kwargs": {"method": "InputXGradient",},
@@ -506,26 +588,9 @@ def test_non_sensitivity(
                 },
                 "call": {
                     "explain_func": explain,
-                    "explain_func_kwargs": {"method": "InputxGradient",},
-                },
-            },
-            {"dtypes": [True, False]},
-        ),
-        (
-            lazy_fixture("load_1d_3ch_conv_model"),
-            lazy_fixture("almost_uniform_1d"),
-            {
-                "a_batch_generate": False,
-                "init": {
-                    "abs": False,
-                    "normalise": False,
-                    "input_shift": -1,
-                    "disable_warnings": True,
-                    "display_progressbar": False,
-                },
-                "call": {
-                    "explain_func": explain,
-                    "explain_func_kwargs": {"method": "Saliency",},
+                    "explain_func_kwargs": {
+                        "method": "Saliency",
+                    },
                 },
             },
             {"dtypes": [True, False]},
@@ -544,7 +609,9 @@ def test_non_sensitivity(
                 },
                 "call": {
                     "explain_func": explain,
-                    "explain_func_kwargs": {"method": "Saliency",},
+                    "explain_func_kwargs": {
+                        "method": "Saliency",
+                    },
                 },
             },
             {"dtypes": [True, False]},
@@ -563,7 +630,9 @@ def test_non_sensitivity(
                 },
                 "call": {
                     "explain_func": explain,
-                    "explain_func_kwargs": {"method": "InputXGradient",},
+                    "explain_func_kwargs": {
+                        "method": "InputXGradient",
+                    },
                 },
             },
             {"dtypes": [True, False]},
@@ -571,7 +640,10 @@ def test_non_sensitivity(
     ],
 )
 def test_input_invariance(
-    model, data: np.ndarray, params: dict, expected: Union[float, dict, bool],
+    model,
+    data: np.ndarray,
+    params: dict,
+    expected: Union[float, dict, bool],
 ):
     x_batch, y_batch = (
         data["x_batch"],
@@ -585,7 +657,10 @@ def test_input_invariance(
         explain = call_params["explain_func"]
         explain_func_kwargs = call_params.get("explain_func_kwargs", {})
         a_batch = explain(
-            model=model, inputs=x_batch, targets=y_batch, **explain_func_kwargs,
+            model=model,
+            inputs=x_batch,
+            targets=y_batch,
+            **explain_func_kwargs,
         )
     elif "a_batch" in data:
         a_batch = data["a_batch"]
@@ -593,7 +668,11 @@ def test_input_invariance(
         a_batch = None
 
     scores = InputInvariance(**init_params)(
-        model=model, x_batch=x_batch, y_batch=y_batch, a_batch=a_batch, **call_params,
+        model=model,
+        x_batch=x_batch,
+        y_batch=y_batch,
+        a_batch=a_batch,
+        **call_params,
     )
 
     assert np.all([s in expected["dtypes"] for s in scores]), "Test failed."
