@@ -2,6 +2,7 @@ from typing import Union
 
 import pytest
 from pytest_lazyfixture import lazy_fixture
+import numpy as np
 
 from quantus.functions.explanation_func import explain
 from quantus.functions.perturb_func import (
@@ -27,7 +28,6 @@ from quantus.metrics.faithfulness import (
     SensitivityN,
     Sufficiency,
 )
-from tests.fixtures import *
 
 
 @pytest.mark.faithfulness
@@ -49,7 +49,9 @@ from tests.fixtures import *
                 },
                 "call": {
                     "explain_func": explain,
-                    "explain_func_kwargs": {"method": "Saliency",},
+                    "explain_func_kwargs": {
+                        "method": "Saliency",
+                    },
                 },
             },
             {"min": -1.0, "max": 1.0},
@@ -69,7 +71,9 @@ from tests.fixtures import *
                 },
                 "call": {
                     "explain_func": explain,
-                    "explain_func_kwargs": {"method": "Saliency",},
+                    "explain_func_kwargs": {
+                        "method": "Saliency",
+                    },
                 },
             },
             {"min": -1.0, "max": 1.0},
@@ -89,7 +93,9 @@ from tests.fixtures import *
                 },
                 "call": {
                     "explain_func": explain,
-                    "explain_func_kwargs": {"method": "Saliency",},
+                    "explain_func_kwargs": {
+                        "method": "Saliency",
+                    },
                 },
             },
             {"min": -1.0, "max": 1.0},
@@ -108,7 +114,9 @@ from tests.fixtures import *
                 },
                 "call": {
                     "explain_func": explain,
-                    "explain_func_kwargs": {"method": "Saliency",},
+                    "explain_func_kwargs": {
+                        "method": "Saliency",
+                    },
                 },
             },
             {"min": -1.0, "max": 1.0},
@@ -128,7 +136,9 @@ from tests.fixtures import *
                 },
                 "call": {
                     "explain_func": explain,
-                    "explain_func_kwargs": {"method": "IntegratedGradients",},
+                    "explain_func_kwargs": {
+                        "method": "IntegratedGradients",
+                    },
                 },
             },
             {"min": -1.0, "max": 1.0},
@@ -147,7 +157,7 @@ from tests.fixtures import *
                 },
                 "call": {
                     "explain_func": explain,
-                    "explain_func_kwargs": {"method": "InputXGradient",},
+                    "explain_func_kwargs": {"method": "GradientsInput",},
                 },
             },
             {"min": -1.0, "max": 1.0},
@@ -166,7 +176,9 @@ from tests.fixtures import *
                     "disable_warnings": False,
                     "display_progressbar": False,
                 },
-                "call": {"explain_func": explain,},
+                "call": {
+                    "explain_func": explain,
+                },
             },
             {"min": -1.0, "max": 1.0},
         ),
@@ -222,14 +234,19 @@ from tests.fixtures import *
                     "disable_warnings": False,
                     "display_progressbar": False,
                 },
-                "call": {"explain_func": explain,},
+                "call": {
+                    "explain_func": explain,
+                },
             },
             {"exception": ValueError},
         ),
     ],
 )
 def test_faithfulness_correlation(
-    model, data: np.ndarray, params: dict, expected: Union[float, dict, bool],
+    model,
+    data: np.ndarray,
+    params: dict,
+    expected: Union[float, dict, bool],
 ):
     x_batch, y_batch = (
         data["x_batch"],
@@ -243,7 +260,10 @@ def test_faithfulness_correlation(
         explain = call_params["explain_func"]
         explain_func_kwargs = call_params.get("explain_func_kwargs", {})
         a_batch = explain(
-            model=model, inputs=x_batch, targets=y_batch, **explain_func_kwargs,
+            model=model,
+            inputs=x_batch,
+            targets=y_batch,
+            **explain_func_kwargs,
         )
     elif "a_batch" in data:
         a_batch = data["a_batch"]
@@ -262,7 +282,11 @@ def test_faithfulness_correlation(
         return
 
     scores = FaithfulnessCorrelation(**init_params)(
-        model=model, x_batch=x_batch, y_batch=y_batch, a_batch=a_batch, **call_params,
+        model=model,
+        x_batch=x_batch,
+        y_batch=y_batch,
+        a_batch=a_batch,
+        **call_params,
     )[0]
 
     assert np.all(
@@ -288,7 +312,9 @@ def test_faithfulness_correlation(
                 },
                 "call": {
                     "explain_func": explain,
-                    "explain_func_kwargs": {"method": "Saliency",},
+                    "explain_func_kwargs": {
+                        "method": "Saliency",
+                    },
                 },
             },
             {"min": -1.0, "max": 1.0},
@@ -307,7 +333,9 @@ def test_faithfulness_correlation(
                 },
                 "call": {
                     "explain_func": explain,
-                    "explain_func_kwargs": {"method": "Saliency",},
+                    "explain_func_kwargs": {
+                        "method": "Saliency",
+                    },
                 },
             },
             {"min": -1.0, "max": 1.0},
@@ -326,7 +354,9 @@ def test_faithfulness_correlation(
                 },
                 "call": {
                     "explain_func": explain,
-                    "explain_func_kwargs": {"method": "Gradient",},
+                    "explain_func_kwargs": {
+                        "method": "Gradient",
+                    },
                 },
             },
             {"min": -1.0, "max": 1.0},
@@ -347,7 +377,9 @@ def test_faithfulness_correlation(
                 },
                 "call": {
                     "explain_func": explain,
-                    "explain_func_kwargs": {"method": "Gradient",},
+                    "explain_func_kwargs": {
+                        "method": "Gradient",
+                    },
                 },
             },
             {"min": 0.0, "max": 1.0},
@@ -366,7 +398,9 @@ def test_faithfulness_correlation(
                 },
                 "call": {
                     "explain_func": explain,
-                    "explain_func_kwargs": {"method": "Saliency",},
+                    "explain_func_kwargs": {
+                        "method": "Saliency",
+                    },
                 },
             },
             {"min": -1.0, "max": 1.0},
@@ -391,7 +425,10 @@ def test_faithfulness_correlation(
     ],
 )
 def test_faithfulness_estimate(
-    model, data: np.ndarray, params: dict, expected: Union[float, dict, bool],
+    model,
+    data: np.ndarray,
+    params: dict,
+    expected: Union[float, dict, bool],
 ):
     x_batch, y_batch = (
         data["x_batch"],
@@ -405,14 +442,21 @@ def test_faithfulness_estimate(
         explain = call_params["explain_func"]
         explain_func_kwargs = call_params.get("explain_func_kwargs", {})
         a_batch = explain(
-            model=model, inputs=x_batch, targets=y_batch, **explain_func_kwargs,
+            model=model,
+            inputs=x_batch,
+            targets=y_batch,
+            **explain_func_kwargs,
         )
     elif "a_batch" in data:
         a_batch = data["a_batch"]
     else:
         a_batch = None
     scores = FaithfulnessEstimate(**init_params)(
-        model=model, x_batch=x_batch, y_batch=y_batch, a_batch=a_batch, **call_params,
+        model=model,
+        x_batch=x_batch,
+        y_batch=y_batch,
+        a_batch=a_batch,
+        **call_params,
     )
 
     assert all(
@@ -437,7 +481,9 @@ def test_faithfulness_estimate(
                 },
                 "call": {
                     "explain_func": explain,
-                    "explain_func_kwargs": {"method": "Saliency",},
+                    "explain_func_kwargs": {
+                        "method": "Saliency",
+                    },
                 },
             },
             {"min": 0.0, "max": 80.0},
@@ -457,7 +503,9 @@ def test_faithfulness_estimate(
                 },
                 "call": {
                     "explain_func": explain,
-                    "explain_func_kwargs": {"method": "Saliency",},
+                    "explain_func_kwargs": {
+                        "method": "Saliency",
+                    },
                 },
             },
             {"min": 0.0, "max": 80.0},
@@ -475,7 +523,9 @@ def test_faithfulness_estimate(
                 },
                 "call": {
                     "explain_func": explain,
-                    "explain_func_kwargs": {"method": "Saliency",},
+                    "explain_func_kwargs": {
+                        "method": "Saliency",
+                    },
                 },
             },
             {"min": 0.0, "max": 80.0},
@@ -499,7 +549,10 @@ def test_faithfulness_estimate(
     ],
 )
 def test_iterative_removal_of_features(
-    model, data: np.ndarray, params: dict, expected: Union[float, dict, bool],
+    model,
+    data: np.ndarray,
+    params: dict,
+    expected: Union[float, dict, bool],
 ):
     x_batch, y_batch = (
         data["x_batch"],
@@ -513,7 +566,10 @@ def test_iterative_removal_of_features(
         explain = call_params["explain_func"]
         explain_func_kwargs = call_params.get("explain_func_kwargs", {})
         a_batch = explain(
-            model=model, inputs=x_batch, targets=y_batch, **explain_func_kwargs,
+            model=model,
+            inputs=x_batch,
+            targets=y_batch,
+            **explain_func_kwargs,
         )
     elif "a_batch" in data:
         a_batch = data["a_batch"]
@@ -532,7 +588,11 @@ def test_iterative_removal_of_features(
         return
 
     scores = IROF(**init_params)(
-        model=model, x_batch=x_batch, y_batch=y_batch, a_batch=a_batch, **call_params,
+        model=model,
+        x_batch=x_batch,
+        y_batch=y_batch,
+        a_batch=a_batch,
+        **call_params,
     )
 
     assert all(
@@ -558,7 +618,9 @@ def test_iterative_removal_of_features(
                 },
                 "call": {
                     "explain_func": explain,
-                    "explain_func_kwargs": {"method": "Saliency",},
+                    "explain_func_kwargs": {
+                        "method": "Saliency",
+                    },
                 },
             },
             {"allowed_dtypes": [True, False]},
@@ -577,7 +639,9 @@ def test_iterative_removal_of_features(
                 },
                 "call": {
                     "explain_func": explain,
-                    "explain_func_kwargs": {"method": "Saliency",},
+                    "explain_func_kwargs": {
+                        "method": "Saliency",
+                    },
                 },
             },
             {"allowed_dtypes": [True, False]},
@@ -597,7 +661,9 @@ def test_iterative_removal_of_features(
                 },
                 "call": {
                     "explain_func": explain,
-                    "explain_func_kwargs": {"method": "Gradient",},
+                    "explain_func_kwargs": {
+                        "method": "Gradient",
+                    },
                 },
             },
             {"allowed_dtypes": [True, False]},
@@ -616,7 +682,9 @@ def test_iterative_removal_of_features(
                 },
                 "call": {
                     "explain_func": explain,
-                    "explain_func_kwargs": {"method": "Saliency",},
+                    "explain_func_kwargs": {
+                        "method": "Saliency",
+                    },
                 },
             },
             {"allowed_dtypes": [True, False]},
@@ -641,7 +709,10 @@ def test_iterative_removal_of_features(
     ],
 )
 def test_monotonicity_arya(
-    model, data: np.ndarray, params: dict, expected: Union[float, dict, bool],
+    model,
+    data: np.ndarray,
+    params: dict,
+    expected: Union[float, dict, bool],
 ):
     x_batch, y_batch = (
         data["x_batch"],
@@ -655,14 +726,21 @@ def test_monotonicity_arya(
         explain = call_params["explain_func"]
         explain_func_kwargs = call_params.get("explain_func_kwargs", {})
         a_batch = explain(
-            model=model, inputs=x_batch, targets=y_batch, **explain_func_kwargs,
+            model=model,
+            inputs=x_batch,
+            targets=y_batch,
+            **explain_func_kwargs,
         )
     elif "a_batch" in data:
         a_batch = data["a_batch"]
     else:
         a_batch = None
     scores = Monotonicity(**init_params)(
-        model=model, x_batch=x_batch, y_batch=y_batch, a_batch=a_batch, **call_params,
+        model=model,
+        x_batch=x_batch,
+        y_batch=y_batch,
+        a_batch=a_batch,
+        **call_params,
     )
 
     assert all(s in expected["allowed_dtypes"] for s in scores), "Test failed."
@@ -690,7 +768,9 @@ def test_monotonicity_arya(
                 },
                 "call": {
                     "explain_func": explain,
-                    "explain_func_kwargs": {"method": "Saliency",},
+                    "explain_func_kwargs": {
+                        "method": "Saliency",
+                    },
                 },
             },
             1.0,
@@ -713,7 +793,9 @@ def test_monotonicity_arya(
                 },
                 "call": {
                     "explain_func": explain,
-                    "explain_func_kwargs": {"method": "Saliency",},
+                    "explain_func_kwargs": {
+                        "method": "Saliency",
+                    },
                 },
             },
             1.0,
@@ -741,7 +823,10 @@ def test_monotonicity_arya(
     ],
 )
 def test_monotonicity_correlation(
-    model, data: np.ndarray, params: dict, expected: Union[float, dict, bool],
+    model,
+    data: np.ndarray,
+    params: dict,
+    expected: Union[float, dict, bool],
 ):
     x_batch, y_batch = (
         data["x_batch"],
@@ -755,14 +840,21 @@ def test_monotonicity_correlation(
         explain = call_params["explain_func"]
         explain_func_kwargs = call_params.get("explain_func_kwargs", {})
         a_batch = explain(
-            model=model, inputs=x_batch, targets=y_batch, **explain_func_kwargs,
+            model=model,
+            inputs=x_batch,
+            targets=y_batch,
+            **explain_func_kwargs,
         )
     elif "a_batch" in data:
         a_batch = data["a_batch"]
     else:
         a_batch = None
     scores = MonotonicityCorrelation(**init_params)(
-        model=model, x_batch=x_batch, y_batch=y_batch, a_batch=a_batch, **call_params,
+        model=model,
+        x_batch=x_batch,
+        y_batch=y_batch,
+        a_batch=a_batch,
+        **call_params,
     )
 
     assert scores is not None, "Test failed."
@@ -787,7 +879,9 @@ def test_monotonicity_correlation(
                 },
                 "call": {
                     "explain_func": explain,
-                    "explain_func_kwargs": {"method": "Saliency",},
+                    "explain_func_kwargs": {
+                        "method": "Saliency",
+                    },
                 },
             },
             {"min": 0.0, "max": 1.0},
@@ -806,7 +900,9 @@ def test_monotonicity_correlation(
                 },
                 "call": {
                     "explain_func": explain,
-                    "explain_func_kwargs": {"method": "Saliency",},
+                    "explain_func_kwargs": {
+                        "method": "Saliency",
+                    },
                 },
             },
             {"min": 0.0, "max": 1.0},
@@ -825,7 +921,9 @@ def test_monotonicity_correlation(
                 },
                 "call": {
                     "explain_func": explain,
-                    "explain_func_kwargs": {"method": "Saliency",},
+                    "explain_func_kwargs": {
+                        "method": "Saliency",
+                    },
                 },
             },
             {"min": 0.0, "max": 1.0},
@@ -844,7 +942,9 @@ def test_monotonicity_correlation(
                 },
                 "call": {
                     "explain_func": explain,
-                    "explain_func_kwargs": {"method": "Saliency",},
+                    "explain_func_kwargs": {
+                        "method": "Saliency",
+                    },
                 },
             },
             {"min": 0.0, "max": 1.0},
@@ -863,7 +963,9 @@ def test_monotonicity_correlation(
                 },
                 "call": {
                     "explain_func": explain,
-                    "explain_func_kwargs": {"method": "Saliency",},
+                    "explain_func_kwargs": {
+                        "method": "Saliency",
+                    },
                 },
             },
             {"min": 0.0, "max": 1.0},
@@ -898,7 +1000,9 @@ def test_monotonicity_correlation(
                 },
                 "call": {
                     "explain_func": explain,
-                    "explain_func_kwargs": {"method": "Saliency",},
+                    "explain_func_kwargs": {
+                        "method": "Saliency",
+                    },
                 },
             },
             {"min": 0.0, "max": 14.0},
@@ -922,7 +1026,10 @@ def test_monotonicity_correlation(
     ],
 )
 def test_pixel_flipping(
-    model, data: np.ndarray, params: dict, expected: Union[float, dict, bool],
+    model,
+    data: np.ndarray,
+    params: dict,
+    expected: Union[float, dict, bool],
 ):
     x_batch, y_batch = (
         data["x_batch"],
@@ -936,7 +1043,10 @@ def test_pixel_flipping(
         explain = call_params["explain_func"]
         explain_func_kwargs = call_params.get("explain_func_kwargs", {})
         a_batch = explain(
-            model=model, inputs=x_batch, targets=y_batch, **explain_func_kwargs,
+            model=model,
+            inputs=x_batch,
+            targets=y_batch,
+            **explain_func_kwargs,
         )
     elif "a_batch" in data:
         a_batch = data["a_batch"]
@@ -946,7 +1056,11 @@ def test_pixel_flipping(
     metric = PixelFlipping(**init_params)
 
     scores = metric(
-        model=model, x_batch=x_batch, y_batch=y_batch, a_batch=a_batch, **call_params,
+        model=model,
+        x_batch=x_batch,
+        y_batch=y_batch,
+        a_batch=a_batch,
+        **call_params,
     )
 
     assert all(
@@ -977,7 +1091,9 @@ def test_pixel_flipping(
                 },
                 "call": {
                     "explain_func": explain,
-                    "explain_func_kwargs": {"method": "Saliency",},
+                    "explain_func_kwargs": {
+                        "method": "Saliency",
+                    },
                 },
             },
             {"min": -1.0, "max": 1.0},
@@ -997,7 +1113,9 @@ def test_pixel_flipping(
                 },
                 "call": {
                     "explain_func": explain,
-                    "explain_func_kwargs": {"method": "Saliency",},
+                    "explain_func_kwargs": {
+                        "method": "Saliency",
+                    },
                 },
             },
             {"min": -1.0, "max": 1.0},
@@ -1017,7 +1135,9 @@ def test_pixel_flipping(
                 },
                 "call": {
                     "explain_func": explain,
-                    "explain_func_kwargs": {"method": "Saliency",},
+                    "explain_func_kwargs": {
+                        "method": "Saliency",
+                    },
                 },
             },
             {"min": -1.0, "max": 1.0},
@@ -1027,7 +1147,10 @@ def test_pixel_flipping(
             lazy_fixture("almost_uniform_1d"),
             {
                 "a_batch_generate": False,
-                "init": {"disable_warnings": True, "display_progressbar": False,},
+                "init": {
+                    "disable_warnings": True,
+                    "display_progressbar": False,
+                },
                 "call": {},
             },
             {"min": -1.0, "max": 1.0},
@@ -1046,7 +1169,9 @@ def test_pixel_flipping(
                 },
                 "call": {
                     "explain_func": explain,
-                    "explain_func_kwargs": {"method": "Saliency",},
+                    "explain_func_kwargs": {
+                        "method": "Saliency",
+                    },
                 },
             },
             {"min": -1.0, "max": 1.0},
@@ -1065,7 +1190,9 @@ def test_pixel_flipping(
                 },
                 "call": {
                     "explain_func": explain,
-                    "explain_func_kwargs": {"method": "Saliency",},
+                    "explain_func_kwargs": {
+                        "method": "Saliency",
+                    },
                 },
             },
             {"min": -1.0, "max": 1.0},
@@ -1073,7 +1200,10 @@ def test_pixel_flipping(
     ],
 )
 def test_region_perturbation(
-    model, data: np.ndarray, params: dict, expected: Union[float, dict, bool],
+    model,
+    data: np.ndarray,
+    params: dict,
+    expected: Union[float, dict, bool],
 ):
     x_batch, y_batch = (
         data["x_batch"],
@@ -1087,7 +1217,10 @@ def test_region_perturbation(
         explain = call_params["explain_func"]
         explain_func_kwargs = call_params.get("explain_func_kwargs", {})
         a_batch = explain(
-            model=model, inputs=x_batch, targets=y_batch, **explain_func_kwargs,
+            model=model,
+            inputs=x_batch,
+            targets=y_batch,
+            **explain_func_kwargs,
         )
     elif "a_batch" in data:
         a_batch = data["a_batch"]
@@ -1097,7 +1230,11 @@ def test_region_perturbation(
     metric = RegionPerturbation(**init_params)
 
     scores = metric(
-        model=model, x_batch=x_batch, y_batch=y_batch, a_batch=a_batch, **call_params,
+        model=model,
+        x_batch=x_batch,
+        y_batch=y_batch,
+        a_batch=a_batch,
+        **call_params,
     )
 
     assert all(
@@ -1127,7 +1264,9 @@ def test_region_perturbation(
                 },
                 "call": {
                     "explain_func": explain,
-                    "explain_func_kwargs": {"method": "Saliency",},
+                    "explain_func_kwargs": {
+                        "method": "Saliency",
+                    },
                 },
             },
             {"type": np.float64},
@@ -1146,7 +1285,9 @@ def test_region_perturbation(
                 },
                 "call": {
                     "explain_func": explain,
-                    "explain_func_kwargs": {"method": "Saliency",},
+                    "explain_func_kwargs": {
+                        "method": "Saliency",
+                    },
                 },
             },
             {"type": np.float64},
@@ -1164,7 +1305,7 @@ def test_region_perturbation(
                 },
                 "call": {
                     "explain_func": explain,
-                    "explain_func_kwargs": {"method": "Gradient",},
+                    "explain_func_kwargs": {"method": "VanillaGradients",},
                 },
             },
             {"type": np.float64},
@@ -1183,7 +1324,9 @@ def test_region_perturbation(
                 },
                 "call": {
                     "explain_func": explain,
-                    "explain_func_kwargs": {"method": "Saliency",},
+                    "explain_func_kwargs": {
+                        "method": "Saliency",
+                    },
                 },
             },
             {"type": np.float64},
@@ -1220,7 +1363,9 @@ def test_region_perturbation(
                 },
                 "call": {
                     "explain_func": explain,
-                    "explain_func_kwargs": {"method": "Saliency",},
+                    "explain_func_kwargs": {
+                        "method": "Saliency",
+                    },
                 },
             },
             {"type": np.float64},
@@ -1240,7 +1385,9 @@ def test_region_perturbation(
                 },
                 "call": {
                     "explain_func": explain,
-                    "explain_func_kwargs": {"method": "Saliency",},
+                    "explain_func_kwargs": {
+                        "method": "Saliency",
+                    },
                 },
             },
             {"type": np.float64},
@@ -1248,7 +1395,10 @@ def test_region_perturbation(
     ],
 )
 def test_selectivity(
-    model, data: np.ndarray, params: dict, expected: Union[float, dict, bool],
+    model,
+    data: np.ndarray,
+    params: dict,
+    expected: Union[float, dict, bool],
 ):
     x_batch, y_batch = (
         data["x_batch"],
@@ -1262,7 +1412,10 @@ def test_selectivity(
         explain = call_params["explain_func"]
         explain_func_kwargs = call_params.get("explain_func_kwargs", {})
         a_batch = explain(
-            model=model, inputs=x_batch, targets=y_batch, **explain_func_kwargs,
+            model=model,
+            inputs=x_batch,
+            targets=y_batch,
+            **explain_func_kwargs,
         )
     elif "a_batch" in data:
         a_batch = data["a_batch"]
@@ -1272,7 +1425,11 @@ def test_selectivity(
     metric = Selectivity(**init_params)
 
     scores = metric(
-        model=model, x_batch=x_batch, y_batch=y_batch, a_batch=a_batch, **call_params,
+        model=model,
+        x_batch=x_batch,
+        y_batch=y_batch,
+        a_batch=a_batch,
+        **call_params,
     )
 
     assert type(metric.get_auc_score) == expected["type"], "Test failed."
@@ -1298,7 +1455,9 @@ def test_selectivity(
                 },
                 "call": {
                     "explain_func": explain,
-                    "explain_func_kwargs": {"method": "Saliency",},
+                    "explain_func_kwargs": {
+                        "method": "Saliency",
+                    },
                 },
             },
             {"min": -1.0, "max": 1.0},
@@ -1318,7 +1477,9 @@ def test_selectivity(
                 },
                 "call": {
                     "explain_func": explain,
-                    "explain_func_kwargs": {"method": "Saliency",},
+                    "explain_func_kwargs": {
+                        "method": "Saliency",
+                    },
                 },
             },
             {"min": -1.0, "max": 1.0},
@@ -1339,7 +1500,9 @@ def test_selectivity(
                 },
                 "call": {
                     "explain_func": explain,
-                    "explain_func_kwargs": {"method": "Gradient",},
+                    "explain_func_kwargs": {
+                        "method": "Gradient",
+                    },
                 },
             },
             {"min": -1.0, "max": 1.0},
@@ -1360,7 +1523,9 @@ def test_selectivity(
                 },
                 "call": {
                     "explain_func": explain,
-                    "explain_func_kwargs": {"method": "Saliency",},
+                    "explain_func_kwargs": {
+                        "method": "Saliency",
+                    },
                 },
             },
             {"min": -1.0, "max": 1.0},
@@ -1401,7 +1566,9 @@ def test_selectivity(
                 },
                 "call": {
                     "explain_func": explain,
-                    "explain_func_kwargs": {"method": "Saliency",},
+                    "explain_func_kwargs": {
+                        "method": "Saliency",
+                    },
                 },
             },
             {"min": -1.0, "max": 1.0},
@@ -1409,7 +1576,10 @@ def test_selectivity(
     ],
 )
 def test_sensitivity_n(
-    model, data: np.ndarray, params: dict, expected: Union[float, dict, bool],
+    model,
+    data: np.ndarray,
+    params: dict,
+    expected: Union[float, dict, bool],
 ):
     x_batch, y_batch = (
         data["x_batch"],
@@ -1423,14 +1593,21 @@ def test_sensitivity_n(
         explain = call_params["explain_func"]
         explain_func_kwargs = call_params.get("explain_func_kwargs", {})
         a_batch = explain(
-            model=model, inputs=x_batch, targets=y_batch, **explain_func_kwargs,
+            model=model,
+            inputs=x_batch,
+            targets=y_batch,
+            **explain_func_kwargs,
         )
     elif "a_batch" in data:
         a_batch = data["a_batch"]
     else:
         a_batch = None
     scores = SensitivityN(**init_params)(
-        model=model, x_batch=x_batch, y_batch=y_batch, a_batch=a_batch, **call_params,
+        model=model,
+        x_batch=x_batch,
+        y_batch=y_batch,
+        a_batch=a_batch,
+        **call_params,
     )
 
     assert all(
@@ -1457,7 +1634,9 @@ def test_sensitivity_n(
                 },
                 "call": {
                     "explain_func": explain,
-                    "explain_func_kwargs": {"method": "Saliency",},
+                    "explain_func_kwargs": {
+                        "method": "Saliency",
+                    },
                 },
             },
             {},
@@ -1478,7 +1657,9 @@ def test_sensitivity_n(
                 },
                 "call": {
                     "explain_func": explain,
-                    "explain_func_kwargs": {"method": "Saliency",},
+                    "explain_func_kwargs": {
+                        "method": "Saliency",
+                    },
                 },
             },
             {},
@@ -1509,7 +1690,10 @@ def test_sensitivity_n(
     ],
 )
 def test_infidelity(
-    model, data: np.ndarray, params: dict, expected: Union[float, dict, bool],
+    model,
+    data: np.ndarray,
+    params: dict,
+    expected: Union[float, dict, bool],
 ):
     x_batch, y_batch = (
         data["x_batch"],
@@ -1523,7 +1707,10 @@ def test_infidelity(
         explain = call_params["explain_func"]
         explain_func_kwargs = call_params.get("explain_func_kwargs", {})
         a_batch = explain(
-            model=model, inputs=x_batch, targets=y_batch, **explain_func_kwargs,
+            model=model,
+            inputs=x_batch,
+            targets=y_batch,
+            **explain_func_kwargs,
         )
     elif "a_batch" in data:
         a_batch = data["a_batch"]
@@ -1531,7 +1718,11 @@ def test_infidelity(
         a_batch = None
 
     scores = Infidelity(**init_params)(
-        model=model, x_batch=x_batch, y_batch=y_batch, a_batch=a_batch, **call_params,
+        model=model,
+        x_batch=x_batch,
+        y_batch=y_batch,
+        a_batch=a_batch,
+        **call_params,
     )
 
     assert scores is not None, "Test failed."
@@ -1555,7 +1746,9 @@ def test_infidelity(
                 },
                 "call": {
                     "explain_func": explain,
-                    "explain_func_kwargs": {"method": "Saliency",},
+                    "explain_func_kwargs": {
+                        "method": "Saliency",
+                    },
                 },
             },
             {"min": 0.0, "max": 1.0},
@@ -1575,7 +1768,9 @@ def test_infidelity(
                 },
                 "call": {
                     "explain_func": explain,
-                    "explain_func_kwargs": {"method": "Saliency",},
+                    "explain_func_kwargs": {
+                        "method": "Saliency",
+                    },
                 },
             },
             {"min": 0.0, "max": 1.0},
@@ -1583,7 +1778,10 @@ def test_infidelity(
     ],
 )
 def test_ROAD(
-    model, data: np.ndarray, params: dict, expected: Union[float, dict, bool],
+    model,
+    data: np.ndarray,
+    params: dict,
+    expected: Union[float, dict, bool],
 ):
     x_batch, y_batch = (
         data["x_batch"],
@@ -1597,14 +1795,21 @@ def test_ROAD(
         explain = call_params["explain_func"]
         explain_func_kwargs = call_params.get("explain_func_kwargs", {})
         a_batch = explain(
-            model=model, inputs=x_batch, targets=y_batch, **explain_func_kwargs,
+            model=model,
+            inputs=x_batch,
+            targets=y_batch,
+            **explain_func_kwargs,
         )
     elif "a_batch" in data:
         a_batch = data["a_batch"]
     else:
         a_batch = None
     scores = ROAD(**init_params)(
-        model=model, x_batch=x_batch, y_batch=y_batch, a_batch=a_batch, **call_params,
+        model=model,
+        x_batch=x_batch,
+        y_batch=y_batch,
+        a_batch=a_batch,
+        **call_params,
     )
     print("scores!!!", scores)
 
@@ -1630,7 +1835,9 @@ def test_ROAD(
                 },
                 "call": {
                     "explain_func": explain,
-                    "explain_func_kwargs": {"method": "Saliency",},
+                    "explain_func_kwargs": {
+                        "method": "Saliency",
+                    },
                 },
             },
             {"min": 0.0, "max": 1.0},
@@ -1649,7 +1856,9 @@ def test_ROAD(
                 },
                 "call": {
                     "explain_func": explain,
-                    "explain_func_kwargs": {"method": "Saliency",},
+                    "explain_func_kwargs": {
+                        "method": "Saliency",
+                    },
                 },
             },
             {"min": 0.0, "max": 1.0},
@@ -1674,7 +1883,10 @@ def test_sufficiency(
         explain = call_params["explain_func"]
         explain_func_kwargs = call_params.get("explain_func_kwargs", {})
         a_batch = explain(
-            model=model, inputs=x_batch, targets=y_batch, **explain_func_kwargs,
+            model=model,
+            inputs=x_batch,
+            targets=y_batch,
+            **explain_func_kwargs,
         )
     elif "a_batch" in data:
         a_batch = data["a_batch"]
@@ -1693,6 +1905,10 @@ def test_sufficiency(
         return
 
     scores = Sufficiency(**init_params)(
-        model=model, x_batch=x_batch, y_batch=y_batch, a_batch=a_batch, **call_params,
+        model=model,
+        x_batch=x_batch,
+        y_batch=y_batch,
+        a_batch=a_batch,
+        **call_params,
     )[0]
     assert (scores >= expected["min"]) & (scores <= expected["max"]), "Test failed."
